import { h } from 'vue'
import NIcon from '../../icon/index'
import {
  InfoIcon,
  SuccessIcon,
  WarningIcon,
  ErrorIcon,
  CloseIcon
} from '../../_base/icons'
import NBaseLoading from '../../_base/loading'
import IconSwitchTransition from '../../_transition/IconSwitchTransition'
import { render } from '../../_utils/vue'
import {
  configurable,
  themeable,
  usecssr
} from '../../_mixins'
import styles from './styles'
import props from './message-props'

export default {
  name: 'Message',
  mixins: [
    configurable,
    themeable,
    usecssr(styles)
  ],
  props,
  methods: {
    handleClose () {
      this.onClose()
    }
  },
  render () {
    const {
      icon,
      type,
      mergedTheme,
      closable,
      content,
      handleClose
    } = this
    return h('div', {
      class: {
        'n-message': true,
        'n-message--closable': closable,
        [`n-message--${type}-type`]: true,
        [`n-${mergedTheme}-theme`]: mergedTheme
      }
    }, [
      h('div', {
        class: 'n-message__icon'
      }, [
        h(NIcon, {
          size: 20
        }, {
          default: () => [
            h(IconSwitchTransition, null, {
              default: () => [
                createIconVNode(icon, type, mergedTheme)
              ]
            })
          ]
        })
      ]),
      h('div', {
        class: 'n-message__content'
      }, [
        h(render, {
          render: content
        })
      ]),
      closable
        ? h('div', {
          class: 'n-message__close'
        }, [
          h(NIcon, {
            onClick: handleClose
          }, {
            default: () => [h(CloseIcon)]
          })
        ])
        : null
    ])
  }
}

function createIconVNode (icon, type, theme) {
  if (typeof icon === 'function') {
    return icon()
  } else {
    switch (type) {
      case 'info':
        return h(InfoIcon, {
          key: 'info'
        })
      case 'success':
        return h(SuccessIcon, {
          key: 'success'
        })
      case 'warning':
        return h(WarningIcon, {
          key: 'warning'
        })
      case 'error':
        return h(ErrorIcon, {
          key: 'error'
        })
      case 'loading':
        return h(NBaseLoading, {
          theme,
          strokeWidth: 24,
          key: 'loading'
        })
    }
  }
}
